@@ -45,21 +45,40 @@ MainWindow::MainWindow(QWidget *parent) :
 {
     ui->setupUi(this);
 
-    /* insert QChartView plotters in ui */
+    /* setup maximums of spinbox */
+    ui->numberSpinBox->setMaximum(std::numeric_limits<int>::max());
+    ui->sealedVolumeDoubleSpinBox->setMaximum(std::numeric_limits<double>::max());
+    ui->portedPortsNumberSpinBox->setMaximum(std::numeric_limits<int>::max());
+    ui->portedVolumeDoubleSpinBox->setMaximum(std::numeric_limits<double>::max());
+    ui->portedPortDiameterDoubleSpinBox->setMaximum(std::numeric_limits<double>::max());
+    ui->portedPortSlotWidthDoubleSpinBox->setMaximum(std::numeric_limits<double>::max());
+    ui->bandPassSealedVolumeDoubleSpinBox->setMaximum(std::numeric_limits<double>::max());
+    ui->bandPassPortedVolumeDoubleSpinBox->setMaximum(std::numeric_limits<double>::max());
+    ui->bandPassPortsNumberSpinBox->setMaximum(std::numeric_limits<int>::max());
+    ui->bandPassPortDiameterDoubleSpinBox->setMaximum(std::numeric_limits<double>::max());
+    ui->bandpassPortSlotWidthDoubleSpinBox->setMaximum(std::numeric_limits<double>::max());
 
+    /* fix minimum width */
+    setMinimumWidth(800);
+    ui->menuBar->setMinimumWidth(800);
+
+    /* insert QChartView plotters in ui */
     QHBoxLayout *ly1 = new QHBoxLayout(ui->sealedVolumePlotWidget);
     sealedPlot = new Plot(tr("Sealed volume frequency response"), ui->sealedVolumePlotWidget);
-    sealedPlot->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Ignored);
+    sealedPlot->setMinimumSize(400, 300);
+    //sealedPlot->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Expanding);
     ly1->insertWidget(0, sealedPlot);
 
     QHBoxLayout *ly2 = new QHBoxLayout(ui->portedPlotWidget);
     portedPlot = new Plot(tr("Ported volume frequency response"), ui->portedPlotWidget);
-    portedPlot->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Ignored);
+    portedPlot->setMinimumSize(400, 300);
+    //portedPlot->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Expanding);
     ly2->insertWidget(0, portedPlot);
 
     QHBoxLayout *ly3 = new QHBoxLayout(ui->bandpassPlotWidget);
     bandpassPlot = new Plot(tr("Bandpass volumes frequency response"), ui->bandpassPlotWidget);
-    bandpassPlot->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Ignored);
+    bandpassPlot->setMinimumSize(400, 300);
+    //bandpassPlot->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Expanding);
     ly3->insertWidget(0, bandpassPlot);
 
     /* test db */
@@ -326,6 +345,13 @@ void MainWindow::syncUiFromCurrentBandPassBox(const BandPassBox& box)
     ui->bandPassPortedResonanceDoubleSpinBox->setValue(box.getPortedBoxResFreq());
     ui->bandPassPortsNumberSpinBox->setValue(box.getPortedBoxPortNum());
     ui->bandPassPortDiameterDoubleSpinBox->setValue(box.getPortedBoxPortDiam());
+    bool slotPortActivated = box.getPortedBoxSlotPortActivated();
+    ui->bandpassPortSlotWidthButton->setChecked(slotPortActivated);
+    ui->bandpassPortSlotWidthButton->clicked(slotPortActivated);
+    ui->bandpassPortSlotWidthDoubleSpinBox->setEnabled(slotPortActivated);
+    ui->bandpassPortSlotHeightLineEdit->setEnabled(slotPortActivated);
+    ui->bandpassPortSlotWidthDoubleSpinBox->setValue(box.getPortedBoxSlotWidth());
+    ui->bandpassPortSlotHeightLineEdit->setText(QString::number(box.getPortedBoxSlotHeight(), 'f', 1));
     ui->bandPassPortLengthLineEdit->setText(QString::number(box.getPortedBoxPortLen(), 'f', 1));
 
     System s(currentSpeaker, &box, currentSpeakerNumber);
@@ -708,6 +734,8 @@ void MainWindow::linkTabs()
     connect(ui->bandPassPortedResonanceDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassPortedResonanceDoubleSpinChanged);
     connect(ui->bandPassPortsNumberSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &MainWindow::onBandPassPortNumSpinChanged);
     connect(ui->bandPassPortDiameterDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassPortDiameterDoubleSpinChanged);
+    connect(ui->bandpassPortSlotWidthButton, &QPushButton::clicked, this, &MainWindow::onBandPassSlotPortActivated);
+    connect(ui->bandpassPortSlotWidthDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassSlotWidthDoubleSpinChanged);
 }
 
 void MainWindow::linkInternals()
@@ -770,6 +798,8 @@ void MainWindow::unlinkTabs()
     disconnect(ui->bandPassPortedResonanceDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassPortedResonanceDoubleSpinChanged);
     disconnect(ui->bandPassPortsNumberSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &MainWindow::onBandPassPortNumSpinChanged);
     disconnect(ui->bandPassPortDiameterDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassPortDiameterDoubleSpinChanged);
+    disconnect(ui->bandpassPortSlotWidthButton, &QPushButton::clicked, this, &MainWindow::onBandPassSlotPortActivated);
+    disconnect(ui->bandpassPortSlotWidthDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassSlotWidthDoubleSpinChanged);
 }
 
 void MainWindow::unlinkInternals()
@@ -1412,6 +1442,33 @@ void MainWindow::changeBPPortedPortDiam(double val)
     syncUiFromCurrentBandPassBox(currentBandPassBox);
 }
 
+void MainWindow::onBandPassSlotPortActivated(bool checked)
+{
+    BPPortedSlotPortCommand* com = new BPPortedSlotPortCommand (this->currentBandPassBox.getPortedBoxSlotPortActivated(), checked, this);
+    this->commandStack->push(com);
+}
+
+void MainWindow::changeBPPortedSlotPortActivation(bool checked)
+{
+    currentBandPassBox.setPortedBoxSlotPortActivated(checked);
+    ui->bandpassPortSlotWidthDoubleSpinBox->setEnabled(checked);
+    ui->bandpassPortSlotHeightLineEdit->setEnabled(checked);
+
+    syncUiFromCurrentBandPassBox(currentBandPassBox);
+}
+
+void MainWindow::changeBPPortedSlotWidth(double val)
+{
+    currentBandPassBox.setPortedBoxSlotWidth(val);
+    syncUiFromCurrentBandPassBox(currentBandPassBox);
+}
+
+void MainWindow::onBandPassSlotWidthDoubleSpinChanged(double val)
+{
+    BPPortedSlotWidthCommand* com = new BPPortedSlotWidthCommand (currentBandPassBox.getPortedBoxSlotWidth(), val, this);
+    this->commandStack->push(com);
+}
+
 void MainWindow::onCurrentBandPassBoxChanged(const BandPassBox &box)
 {
     if (!currentSpeaker.isValid())
